from distutils.core import setup
setup(
  name = 'redlemur',
  packages = ['lemur'],
  version = '0.04',
  description = 'High level visualization library',
  author = 'Ryan Marren',
  author_email = 'rmarren1@jhu.edu',
  url = 'https://github.com/NeuroDataDesign/lemur-f17s18',
  download_url = 'https://github.com/NeuroDataDesign/lemur-f17s18/archive/0.01.tar.gz',
  keywords = ['visualization', 'neuroscience', 'embeddings'],
  classifiers = [],
)
